pub struct LoginUserInfo {
pub token: String,
pub userId: i64,
pub appId: String,
pub xRequestId: String,
pub deviceId: String,
pub vipExpireTime: i64,
}Fields
token: StringuserId: i64appId: StringxRequestId: StringdeviceId: StringvipExpireTime: i64Trait Implementations
Sourceimpl Clone for LoginUserInfo
impl Clone for LoginUserInfo
Sourcefn clone(&self) -> LoginUserInfo
fn clone(&self) -> LoginUserInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LoginUserInfo
impl Debug for LoginUserInfo
Sourceimpl<'de> Deserialize<'de> for LoginUserInfo
impl<'de> Deserialize<'de> for LoginUserInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl<'r> FromRequest<'r> for LoginUserInfo
impl<'r> FromRequest<'r> for LoginUserInfo
Sourcetype Error = ApiTokenError
type Error = ApiTokenError
Sourceimpl FromRequest for LoginUserInfo
impl FromRequest for LoginUserInfo
Sourcetype Future = Ready<Result<LoginUserInfo, <LoginUserInfo as FromRequest>::Error>>
type Future = Ready<Result<LoginUserInfo, <LoginUserInfo as FromRequest>::Error>>
Self. Read moreSourcefn from_request(_: &HttpRequest, _: &mut Payload) -> Self::Future
fn from_request(_: &HttpRequest, _: &mut Payload) -> Self::Future
Self from request parts asynchronously.Sourceimpl JsonSchema for LoginUserInfo
impl JsonSchema for LoginUserInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read moreSourceimpl<'r> OpenApiFromRequest<'r> for LoginUserInfo
Q: My (diesel) database does not implement OpenApiFromRequest.
A: This is because the parameter does not show up in the path, query or body.
So this is considered a Request Guard. There is a derive macro for this,
but this does not work in combination with the #[database(“…”)] marco.
You can solve this my implementing it manually
impl<'r> OpenApiFromRequest<'r> for LoginUserInfo
Q: My (diesel) database does not implement OpenApiFromRequest. A: This is because the parameter does not show up in the path, query or body. So this is considered a Request Guard. There is a derive macro for this, but this does not work in combination with the #[database(“…”)] marco. You can solve this my implementing it manually
Sourcefn from_request_input(
_gen: &mut OpenApiGenerator,
_name: String,
_required: bool,
) -> Result<RequestHeaderInput>
fn from_request_input( _gen: &mut OpenApiGenerator, _name: String, _required: bool, ) -> Result<RequestHeaderInput>
Sourcefn get_responses(_gen: &mut OpenApiGenerator) -> Result<Responses, OpenApiError>
fn get_responses(_gen: &mut OpenApiGenerator) -> Result<Responses, OpenApiError>
Sourceimpl PartialEq for LoginUserInfo
impl PartialEq for LoginUserInfo
Sourceimpl Serialize for LoginUserInfo
impl Serialize for LoginUserInfo
impl Eq for LoginUserInfo
impl StructuralPartialEq for LoginUserInfo